@@ -11,23 +11,23 @@
 #ifndef ANSWERSDIALOG_H
 #define ANSWERSDIALOG_H
 
-#include <kdialog.h>
+#include <QDialog>
 
-#include <QtCore/qvector.h>
+#include <QVector>
 
 class QScrollArea;
 class QWidget;
 
 class userAnswer;
 
-class answersDialog : public KDialog
+class answersDialog : public QDialog
 {
 	public:
 		answersDialog(QWidget *parent, const QVector<userAnswer> &userAnswers, const QString &question, int correctAnswers);
 	
 	private:
 		QWidget *p_container;
-		QScrollArea *p_sa;
+		QScrollArea *p_scrollArea;
 };
 
 #endif
